==> open-xchange-core_7.10.1.orig.tar.bz2: open-xchange-core-7.10.1/com.openexchange.chronos/src/com/openexchange/chronos/RecurrenceId.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.chronos;

import java.util.TimeZone;
import org.dmfs.rfc5545.DateTime;

/**
 * {@link RecurrenceId}
 *
 * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
 * @since v7.10.0
 * @see <a href="https://tools.ietf.org/html/rfc5545#section-3.8.4.4">RFC 5545, section 3.8.4.4</a>
 */
public interface RecurrenceId extends Comparable<RecurrenceId> {

    /**
     * Gets the value, i.e. the (original) start-date of the targeted recurrence in the event series.
     * <p/>
     * The returned date-time is either in <code>UTC</code> format or a <i>floating</i> date or date-time.
     *
     * @return The recurrence-id value
     */
    DateTime getValue();

    /**
     * Gets a value indicating the effective range of targeted recurrence instances.
     *
     * @return The range, or <code>null</code> if only this instance is targeted.
     */
    RecurrenceRange getRange();

    /**
     * Compares this recurrence id to another one, taking a concrete timezone into consideration for <i>floating</i> values.
     *
     * @param other The recurrence id to compare with
     * @param timeZone The timezone to consider for <i>floating</i> dates, i.e. the actual 'perspective' of the comparison, or
     *            <code>null</code> to fall back to UTC
     * @return A negative integer, zero, or a positive integer as this recurrence id is less than, equal to, or greater than the other
     *         recurrence id
     */
    int compareTo(RecurrenceId other, TimeZone timeZone);

}

==> open-xchange-core_7.10.4.orig.tar.bz2: open-xchange-core-7.10.4/com.openexchange.chronos/src/com/openexchange/chronos/RecurrenceId.java <==
/*
 *
 *    OPEN-XCHANGE legal information
 *
 *    All intellectual property rights in the Software are protected by
 *    international copyright laws.
 *
 *
 *    In some countries OX, OX Open-Xchange, open xchange and OXtender
 *    as well as the corresponding Logos OX Open-Xchange and OX are registered
 *    trademarks of the OX Software GmbH group of companies.
 *    The use of the Logos is not covered by the GNU General Public License.
 *    Instead, you are allowed to use these Logos according to the terms and
 *    conditions of the Creative Commons License, Version 2.5, Attribution,
 *    Non-commercial, ShareAlike, and the interpretation of the term
 *    Non-commercial applicable to the aforementioned license is published
 *    on the web site http://www.open-xchange.com/EN/legal/index.html.
 *
 *    Please make sure that third-party modules and libraries are used
 *    according to their respective licenses.
 *
 *    Any modifications to this package must retain all copyright notices
 *    of the original copyright holder(s) for the original code used.
 *
 *    After any such modifications, the original and derivative code shall remain
 *    under the copyright of the copyright holder(s) and/or original author(s)per
 *    the Attribution and Assignment Agreement that can be located at
 *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
 *    given Attribution for the derivative code and a license granting use.
 *
 *     Copyright (C) 2016-2020 OX Software GmbH
 *     Mail: info@open-xchange.com
 *
 *
 *     This program is free software; you can redistribute it and/or modify it
 *     under the terms of the GNU General Public License, Version 2 as published
 *     by the Free Software Foundation.
 *
 *     This program is distributed in the hope that it will be useful, but
 *     WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY
 *     or FITNESS FOR A PARTICULAR PURPOSE. See the GNU General Public License
 *     for more details.
 *
 *     You should have received a copy of the GNU General Public License along
 *     with this program; if not, write to the Free Software Foundation, Inc., 59
 *     Temple Place, Suite 330, Boston, MA 02111-1307 USA
 *
 */

package com.openexchange.chronos;

import java.util.TimeZone;
import org.dmfs.rfc5545.DateTime;

/**
 * {@link RecurrenceId}
 *
 * @author <a href="mailto:tobias.friedrich@open-xchange.com">Tobias Friedrich</a>
 * @since v7.10.0
 * @see <a href="https://tools.ietf.org/html/rfc5545#section-3.8.4.4">RFC 5545, section 3.8.4.4</a>
 */
public interface RecurrenceId extends Comparable<RecurrenceId> {

    /**
     * Gets the value, i.e. the (original) start-date of the targeted recurrence in the event series.
     * <p/>
     * The returned date-time is either in <code>UTC</code> format or a <i>floating</i> date or date-time.
     *
     * @return The recurrence-id value
     */
    DateTime getValue();

    /**
     * Gets a value indicating the effective range of targeted recurrence instances.
     *
     * @return The range, or <code>null</code> if only this instance is targeted.
     */
    RecurrenceRange getRange();

    /**
     * Compares this recurrence id to another one, taking a concrete timezone into consideration for <i>floating</i> values.
     *
     * @param other The recurrence id to compare with
     * @param timeZone The timezone to consider for <i>floating</i> dates, i.e. the actual 'perspective' of the comparison, or
     *            <code>null</code> to fall back to UTC
     * @return A negative integer, zero, or a positive integer as this recurrence id is less than, equal to, or greater than the other
     *         recurrence id
     */
    int compareTo(RecurrenceId other, TimeZone timeZone);

    /**
     * Gets a value indicating whether this recurrence id <i>matches</i> another one, i.e. both are pointing to the same absolute timestamp
     * (although possibly in different timezones for non-<i>floating</i> values, or decorated with a different recurrence range).
     *
     * @param other The recurrent identifier to match
     * @return <code>true</code> if both recurrence ids match, <code>false</code> otherwise
     */
    boolean matches(RecurrenceId other);

}
